@@ -1,3 +1,7 @@
+"""
+Poisson distribution.
+"""
+
 import numba as nb
 import numpy as np
 from ._special import gammaincc as _gammaincc
@@ -10,19 +14,26 @@ _signatures = [
 
 
 @nb.vectorize(_signatures)
-def pmf(k, mu):
+def logpmf(k, mu):
     """
-    Return probability mass for Poisson distribution.
+    Return log of probability mass.
     """
     if mu == 0:
-        return 1.0 if k == 0 else 0.0
-    logp = k * np.log(mu) - _lgamma(k + 1.0) - mu
-    return np.exp(logp)
+        return 0.0 if k == 0 else -np.inf
+    return k * np.log(mu) - _lgamma(k + 1.0) - mu
+
+
+@nb.vectorize(_signatures)
+def pmf(k, mu):
+    """
+    Return probability mass.
+    """
+    return np.exp(logpmf(k, mu))
 
 
 @nb.vectorize(_signatures)
 def cdf(k, mu):
     """
-    Evaluate cumulative distribution function of Poisson distribution.
+    Evaluate cumulative distribution function.
     """
     return _gammaincc(k + 1, mu)
